# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-05-22 20:06
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_uploads', '0004_add_category_and_name_to_images'),
    ]

    operations = [
        migrations.AlterField(
            model_name='uploadedimage',
            name='category',
            field=models.CharField(blank=True, choices=[('organization', 'Organization'), ('project', 'Project')], default=None, max_length=24, null=True, verbose_name='Category'),
        ),
    ]
